@@ -5,7 +5,7 @@ from bergen.query import DelayedGQL
 
 
 CREATE_SAMPLE = DelayedGQL("""
-mutation SampleCreate($name: String!) {
+mutation SampleCreate($name: String) {
   createSample(name: $name){
     id
     name
